﻿--[[
	Project: HideParty
	Version: 3.1
	Website: http://wow.curseforge.com/addons/hideparty/
	Author: Erfolg

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>. 
]] 

HideParty = LibStub("AceAddon-3.0"):NewAddon("HideParty", "AceConsole-3.0", "AceEvent-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("HideParty")
local db = nil

playerHidden = nil
targetHidden = nil
raidHidden = nil

local options = {

name = "HideParty",
handler = HideParty,
type = "group",
	
	args = {
		
		descrp = {
			type = "description",
			order = 0,
			name = L["AddonDescription"],
		},

		sep = {
			type = "header",
			order = 1,
			name = "",
		},

		playerEnabled = {
			type = "toggle",
			order = 2,
			name = L["HidePlayer"],
			desc = L["HidePlayerDesc"],
			get = function() return db.playerEnabled end,
			set = function(info, value) 
			local db = HideParty.db.profile				
			db.playerEnabled = value
			HideParty:UpdateFrames()
			end,
		},
		
		targetEnabled = {
			type = "toggle",
			order = 3,
			name = L["HideTarget"],
			desc = L["HideTargetDesc"],
			get = function() return db.targetEnabled end,
			set = function(info, value) 
			local db = HideParty.db.profile				
			db.targetEnabled = value
			HideParty:UpdateFrames()
			end,
		},

		raidEnabled = {
			type = "toggle",
			order = 4,
			name = L["HideRaid"],
			desc = L["HideRaidDesc"],
			get = function() return db.raidEnabled end,
			set = function(info, value) 
			local db = HideParty.db.profile				
			db.raidEnabled = value
			HideParty:UpdateFrames()
			end,
		},
		
		reloadUI = {
			type = "execute",
			order = 5,
			name = L["ReloadUI"],
			desc = L["ReloadUI"],
			func = 	function()
				ReloadUI()
			end,
		},
	},
}

local defaults = {
	profile = {
	playerEnabled = true,
	targetEnabled = true,
	raidEnabled = true,
	},
}

function HideParty:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("HidePartyDB", defaults, true)
	db = self.db.profile
	LibStub("AceConfig-3.0"):RegisterOptionsTable("HideParty", options)
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("HideParty", "HideParty")
	self:RegisterChatCommand("hideparty", "ChatCommand")
	self:UpdateFrames()
end

function HideParty:UpdateFrames()
	if  self:IsEnabled() and  db.playerEnabled then 
		if not playerEnabled then
	        	isPlayerHidden = true
			HideParty:HPlayer()
		end
	end
	if  self:IsEnabled() and  db.targetEnabled then 
		if not targetEnabled then
	        	isTargetHidden = true
			HideParty:HTarget()
		end
	end
	if self:IsEnabled() and db.raidEnabled then
		if not raidenabled then 
			isRaidHidden = true
			HideParty:HRaid()
		end
	end
end	

function HideParty:OnEnable()
	self:UpdateFrames()
	print (L["OnLoad"])
end

function HideParty:OnDisable()
	self:UpdateFrames()
end

function HideParty:OnProfileChanged()
	self:UpdateFrames()
end

function HideParty:HPlayer()
	PlayerFrame:Hide()
end

function HideParty:HTarget()
	TargetFrame:UnregisterAllEvents()
	TargetFrame:Hide()
	ComboFrame:UnregisterAllEvents()
end

function HideParty:HRaid()
	for players = 1, 4 do
		local frame = _G["PartyMemberFrame"..players]
		frame:UnregisterAllEvents()
		frame:Hide()
		frame.Show = function() end
	end
	
	UIParent:UnregisterEvent("RAID_ROSTER_UPDATE")
	CompactRaidFrameManager:UnregisterAllEvents()
	CompactRaidFrameManager:Hide()
	CompactRaidFrameManager_SetSetting("IsShown", "0")
end

function HideParty:ChatCommand(input)
	if not input or input:trim() == "" then
		InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
	else
		LibStub("AceConfigCmd-3.0").HandleCommand(HideParty, "hideparty", input)
	end
end
